@@ -1,6 +1,6 @@
 package Net::DNS::Nameserver;
 #
-# $Id: Nameserver.pm 516 2005-11-19 12:37:38Z olaf $
+# $Id: Nameserver.pm 590 2006-05-22 21:04:37Z olaf $
 #
 
 use Net::DNS;
@@ -21,7 +21,7 @@ use constant	STATE_GOT_LENGTH => 2;
 use constant	STATE_SENDING => 3;
 use Net::IP qw(ip_is_ipv4 ip_is_ipv6 ip_normalize); 
 
-$VERSION = (qw$LastChangedRevision: 516 $)[1];
+$VERSION = (qw$LastChangedRevision: 590 $)[1];
 
 #@DEFAULT_ADDR is set in the BEGIN block 
 $DEFAULT_PORT=53;
@@ -372,11 +372,22 @@ sub udp_connection {
 
 	local $| = 1 if $self->{"Verbose"};
 	print "Writing response - " if $self->{"Verbose"};
-	# die() ?!??  I think we need something better. --robert
-	$sock->send($reply_data) or die "send: $!";
-	print "done\n" if $self->{"Verbose"};
+
+	if ($sock->send($reply_data)) { # 
+	  print "done\n" if $self->{"Verbose"};
+	}
+	else {
+	  print "failed to send reply: $!\n" if $self->{"Verbose"};
+	}
+      }
+
+
+sub get_open_tcp {
+    my $self=shift;
+    return keys %{$self->{"_tcp"}};
 }
 
+
 #------------------------------------------------------------------------------
 # loop_once - Just check "once" on sockets already set up
 #------------------------------------------------------------------------------
@@ -584,28 +595,44 @@ Start accepting queries. Calling main_loop never returns.
 #
 #  The functionality might change. Left "undocumented" for now.
 #
-#=head2 loop_once
-#
-#	$ns->loop_once( [TIMEOUT_IN_SECONDS] );
-#
-# Start accepting queries, but returns. If called without a parameter,
-# the call will not return until a request has been received (and
-# replied to). If called with a number, that number specifies how many
-# seconds (even fractional) to maximum wait before returning. If called
-# with 0 it will return immediately unless there's something to do.
-# 
-# Handling a request and replying obviously depends on the speed of
-# ReplyHandler. Assuming ReplyHandler is super fast, loop_once should spend
-# just a fraction of a second, if called with a timeout value of 0 seconds.
-# One exception is when an AXFR has requested a huge amount of data that
-# the OS is not ready to receive in full. In that case, it will keep
-# running through a loop (while servicing new requests) until the reply
-# has been sent.
-# 
-# In case loop_once accepted a TCP connection it will immediatly check
-# if there is data to read from the socket. If not it will return and
-# you will have to call loop_once() again to check if there is any
-# data waiting on the socket to be processed.
+=head2 loop_once
+
+	$ns->loop_once( [TIMEOUT_IN_SECONDS] );
+
+Start accepting queries, but returns. If called without a parameter,
+the call will not return until a request has been received (and
+replied to). If called with a number, that number specifies how many
+seconds (even fractional) to maximum wait before returning. If called
+with 0 it will return immediately unless there's something to do.
+
+Handling a request and replying obviously depends on the speed of
+ReplyHandler. Assuming ReplyHandler is super fast, loop_once should spend
+just a fraction of a second, if called with a timeout value of 0 seconds.
+One exception is when an AXFR has requested a huge amount of data that
+the OS is not ready to receive in full. In that case, it will keep
+running through a loop (while servicing new requests) until the reply
+has been sent.
+
+In case loop_once accepted a TCP connection it will immediatly check
+if there is data to be read from the socket. If not it will return and
+you will have to call loop_once() again to check if there is any data
+waiting on the socket to be processed. In most cases you will have to
+count on calling "loop_once" twice.
+
+A code fragment like:
+	$ns->loop_once(10);
+        while( $ns->get_open_tcp() ){
+	      $ns->loop_once(0);
+	}
+
+Would wait for 10 seconds for the initial connection and would then
+process all TCP sockets until none is left. 
+
+=head2 get_open_tcp
+
+In scalar context returns the number of TCP connections for which state
+is maintained. In array context it returns IO::Socket objects, these could
+be useful for troubleshooting but be careful using them.
 
 =head1 EXAMPLE
 
