@@ -1,6 +1,6 @@
 package Net::DNS::RR;
 #
-# $Id: RR.pm 593 2006-05-25 09:40:39Z olaf $
+# $Id: RR.pm 607 2006-09-17 18:20:28Z olaf $
 #
 use strict;
 
@@ -14,7 +14,7 @@ use Net::DNS;
 use Net::DNS::RR::Unknown;
 
 
-$VERSION = (qw$LastChangedRevision: 593 $)[1];
+$VERSION = (qw$LastChangedRevision: 607 $)[1];
 
 =head1 NAME
 
@@ -163,12 +163,24 @@ BEGIN {
 		} else {
 		  # Die only if we are dealing with a version for which DLV is 
 		  # available 
-		  die $@ if (
-			     defined ($Net::DNS::SEC::SVNVERSION) && 
-			     ( $Net::DNS::SEC::SVNVERSION > 591 )
-			    );
+		  die $@ if defined ($Net::DNS::SEC::HAS_DLV) ;
+
 		}
 
+	 	eval { 
+		  local $SIG{'__DIE__'} = 'DEFAULT';
+		  require Net::DNS::RR::NSEC3; 
+		};
+
+		unless ($@) {
+		  $RR{'NSEC3'} =1;
+		} else {
+		  # Die only if we are dealing with a version for which NSEC3 is 
+		  # available 
+		  die $@ if defined ($Net::DNS::SEC::HAS_NSEC3);
+		}
+
+
     }
 }
 
